function [fmod,ftri,Amod,Atri,Uoi_rms,Uo_rms,dh_uoi,dh_uo,SpectrUoi,SpectrUo]=calcc41(OscRecord,iUmod,iUtri,iUoi,iUo,fmod=0,ftri=0)
  
# Calculates parameters of control and output voltages for Exercise C41.
#
# Arguments:
#   - OscRecord -- a structure containing data downloaded from an oscilloscope, 
#       e.g. read from a CSV file using oscread*()
#   - iUmod, iUtri, iUoi, iUo -- waveform indices of: the modulating voltage, 
#       the triangle wave, the bridge output voltage and the filter output 
#       voltage, respectively, as stored in OscRecord; they can be obtained from 
#       from waveform labels using oscchid()
#   - fmod, ftri -- optional arguments that can be used to impose values for 
#       the modulating and carrier (triangle wave) frequencies; if skipped, 
#       these frequencies are determined automatically
#
# Return values:
#   - fmod -- modulating voltage frequency
#   - ftri -- triangle wave frequency
#   - Amod -- modulating voltage magnitude
#   - Atri -- triangle wave magnitude
#   - Uoi_rms -- bridge output voltage rms value
#   - Uo_rms -- filter output voltage rms value
#   - dh_uoi -- bridge output voltage total harmonic distortion
#   - dh_uo -- filter output voltage total harmonic distortion
#   - SpectrUoi -- Spectr structure containing frequency spectrum data for uoi
#   - SpectrUo -- Spectr structure containing frequency spectrum data for uo

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  YHYST=0.01;
  XDEADZONE=0.1;
  
  [t, umod] = oscgetxy(OscRecord, iUmod);
  [t, utri] = oscgetxy(OscRecord, iUtri);
  umodflt = wavglinn(umod, 3);
  utriflt = utri;

  if (fmod == 0)
    fmod = freq(umodflt, t, YHYST, XDEADZONE)
  endif
  if (ftri == 0)
    ftri = freq(utriflt, t, YHYST, XDEADZONE)
  endif
  
  iPer = periodbounds(umodflt, YHYST, XDEADZONE);
  Amod = magper(umodflt, iPer)
  iPer = periodbounds(utriflt, YHYST, XDEADZONE);  
  Atri = magper(utriflt, iPer)

  [SpectrUoi, kfund] = oscspectr(OscRecord, iUoi, fmod);
  [SpectrUo, kfund] = oscspectr(OscRecord, iUo, fmod);
  Uoi_rms = spectrrms(SpectrUoi, -1)
  Uo_rms = spectrrms(SpectrUo, -1)
  dh_uoi = spectrthd(SpectrUoi, kfund)
  dh_uo = spectrthd(SpectrUo, kfund)
  
endfunction
