function mag=magper(y,iPeriodBounds=[])
  
# mag = magper(y, iPeriodBounds)
#
# Determines the magnitude of the alternating component of the periodic signel 
# y, i.e. half of its peak-to-peak value. The magnitude is first determined 
# for each period separately and then an average value is returned.
#
# The optional argument iPeriodBounds can be used to impose specific indices 
# of y to be considered period boundaries. If it is not provided, then these 
# boundaries are established through periodbounds(y-mean(y)).

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
 
  if (isempty(iPeriodBounds))
    iPeriodBounds = periodbounds(y-mean(y));
  endif
  pp = [];
  for j = [1:(length(iPeriodBounds)-1)]
    ymax = max(y(iPeriodBounds(j):iPeriodBounds(j+1)));
    ymin = min(y(iPeriodBounds(j):iPeriodBounds(j+1)));
    pp = [pp (ymax-ymin)];
  end
  mag = mean(pp) / 2;
  
endfunction
