function [Spectr,kfund]=oscspectr(OscRecord,iChannel,ffund=0)
  
# [Spectr, kfund] = oscspectr(OscRecord, iChannel, ffund)
#
# Uses spectr() to calculate the frequency spectrum of an oscilloscope waveform 
# contained in the OscRecord structure and returns a corresponding Spectr 
# structure. The waveform is identified by iChannel which is its numerical index 
# in OscRecord.
#
# The component number in Spectr corresponding to the fundamental frequency 
# ffund is returned in kfund. If ffund is not given, then ifund = 2.
#
# For a description of the Spectr structure, see spectr().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  [t,y] = oscgetxy(OscRecord, iChannel);
  Spectr = spectr(y, t, ffund);
  if (ffund > 0)
    kfund = Spectr.k(findnearest(Spectr.f, ffund));
  else
    kfund = 1;
  endif
  
endfunction
