function plotc41_uspectr(SpectrUoi,SpectrUo,fmax=0)
  
# plotc41_uspectr(SpectrUoi, SpectrUo, fmax)
#
# Plots frequency spectra (rms values) of the bridge output voltage (uoi) and 
# the filter output voltage (uo), as contained in the structures SpectrUoi and 
# Uo, respectively. Frequency components with a value lower than 5% of the 
# largest component are skipped.
#
# The optional parameter fmax can be used to limit the frequency axis at its 
# high end.

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  THR = 0.05;  
  spectrUoiRed = [];
  uthr = THR * max(SpectrUoi.m);
  for j = [1:length(SpectrUoi.m)]
    if (SpectrUoi.m(j) >= uthr)
      spectrUoiRed = [spectrUoiRed; SpectrUoi.f(j), SpectrUoi.rms(j)];
    endif
  endfor
  spectrUoRed = [];
  uthr = THR * max(SpectrUo.m);
  for j = [1:length(SpectrUo.m)]
    if (SpectrUo.m(j) >= uthr)
      spectrUoRed = [spectrUoRed; SpectrUo.f(j), SpectrUo.rms(j)];
    endif
  endfor

  figure();
  stem(spectrUoiRed(:,1), spectrUoiRed(:,2));
  hold on;
  stem(spectrUoRed(:,1), spectrUoRed(:,2));
  legend(["Uoi";"Uo"]);
  xlabel("f / Hz");
  ylabel("Urms / V");
  if (fmax > 0)
    xlim([0 fmax]);
  endif
  grid on;
  
endfunction
