function totrms=spectrrms(Spectr,k=[])
  
# totrms = spectrrms(Spectr, k=[])
#
# Calculates the total rms value of a signal whose spectrum is represented 
# by the structure Spectr.
#
# Through the optional argument k, the calculation can be limited to 
# specific frequency components. It should be a vector containing component 
# numbers, where 0 corresponds to the direct component, 1 corresponds 
# to the first alternating component (which does not necessarily represent the 
# fundamental one) etc.
#
# To calculate the total rms value of the alternating component only, use 
# spectrrms(Spectr, -1), which is equivalent to 
# spectrrms(Spectr, [1:Spectr.n]).
#
# For a description of the Spectr structure, see spectr().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  if (isempty(k))
    totrms = sqrt(sum(Spectr.rms .^ 2));
  elseif (k == -1)
    iac = find(Spectr.k != 0);
    totrms = sqrt(sum(Spectr.rms(iac) .^ 2));
  else
    icomp = [];
    for j=[1:length(k)]
      icomp = [icomp spectrcompidx(Spectr, k(j))];
    endfor
    totrms = sqrt(sum(Spectr.rms(icomp) .^ 2));
  endif
  
endfunction
