function thd=spectrthd(Spectr,kfund=1,ref="f")
  
# thd = spectrthd(Spectr, kfund, ref)
#
# Calculates the total harmonic distortion (THD) of a signal whose spectrum is 
# represented by the structure Spectr.
#
# The argument kfund indicates the number of the frequency component in Spectr 
# to be considered the fundamental frequency. If not provided, it defaults to 1.
#
# The optional argument ref specifies the reference value to be applied, 
# corresponding to the two possible definitions of THD:
#   - "f" (default) -- the rms value of the fundamental frequency
#   - "t" -- the total rms value of the alternating component
#
# For a description of the Spectr structure, see spectr().

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology
  
  iAcExclFund = find(Spectr.k != 0 & Spectr.k != kfund);
  rmsAcExclFund = sqrt(sum(Spectr.rms(iAcExclFund) .^ 2));
  
  ref = tolower(ref);
  if (strcmp(ref, "t"))
    rmsRef = spectrrms(Spectr, -1);
  elseif (strcmp(ref, "f"))
    rmsRef = spectrrms(Spectr, kfund);
  else
    error("Incorrect reference.");
  endif
  
  thd = rmsAcExclFund / rmsRef;
  
endfunction
